============
Installation
============

At the command line::

    $ pip install gerrit-dash-creator

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv gerrit-dash-creator
    $ pip install gerrit-dash-creator
